@@ -17,13 +17,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-adblock-manager.h 6742 2006-12-17 18:09:55Z jframeau $
+ *  $Id: ephy-adblock-manager.h 6931 2007-03-02 23:35:44Z bberg $
  */
 
 #ifndef EPHY_ADBLOCK_MANAGER_H
 #define EPHY_ADBLOCK_MANAGER_H
 
 #include <glib-object.h>
+#include "ephy-embed.h"
 #include "ephy-adblock.h"
 
 G_BEGIN_DECLS
@@ -56,6 +57,7 @@ struct _EphyAdBlockManagerClass {
 GType 			ephy_adblock_manager_get_type (void);
 
 gboolean		ephy_adblock_manager_should_load (EphyAdBlockManager *self,
+				    	 	    	  EphyEmbed *embed,
 				    	 	    	  const char *url,
 				    	 	    	  AdUriCheckType check_type);
 
