@@ -29,7 +29,7 @@
 #define CONF_NETWORK_SOCKS_PROXY_PORT "/system/proxy/socks_port"
 #define CONF_NETWORK_PROXY_AUTO_URL "/system/proxy/autoconfig_url"
 #define CONF_NETWORK_PROXY_IGNORE_HOSTS "/system/http_proxy/ignore_hosts"
-#define CONF_DESKTOP_FONT_VARIABLE "/desktop/gnome/interface/font_name"
+#define CONF_DESKTOP_FONT_VARIABLE "/desktop/gnome/interface/document_font_name"
 #define CONF_DESKTOP_FONT_MONOSPACE "/desktop/gnome/interface/monospace_font_name"
 
 /* DEPRECATED, we migrate them */
