@@ -1,6 +1,7 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encodings.c,v 1.17 2004/12/13 18:58:58 chpe Exp $
+ *  $Id: ephy-encodings.c 6741 2006-12-17 03:06:15Z bjornl $
  */
 
 #include "config.h"
@@ -32,7 +33,7 @@
 
 #define EPHY_ENCODINGS_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_ENCODINGS, EphyEncodingsPrivate))
 
-struct EphyEncodingsPrivate
+struct _EphyEncodingsPrivate
 {
 	EphyNodeDb *db;
 	EphyNode *root;
@@ -140,16 +141,36 @@ encoding_entries [] =
 	{ N_("Unicode (UTF-_32 BE)"),               "UTF-32BE",              0,			FALSE },
 	{ N_("Unicode (UTF-3_2 LE)"),               "UTF-32LE",              0,			FALSE },
 
-	{ N_("Off"),		 		    "",				   LG_NONE,								TRUE },
-	{ N_("Chinese"),			    "zh_parallel_state_machine",   LG_CHINESE_TRAD | LG_CHINESE_SIMP,					TRUE },
-	{ N_("Chinese Simplified"),		    "zhcn_parallel_state_machine", LG_CHINESE_SIMP,							TRUE },
-	{ N_("Chinese Traditional"),		    "zhtw_parallel_state_machine", LG_CHINESE_TRAD,							TRUE },
-	{ N_("East Asian"),			    "cjk_parallel_state_machine",  LG_CHINESE_TRAD | LG_CHINESE_SIMP | LG_JAPANESE | LG_KOREAN,		TRUE },
-	{ N_("Japanese"),			    "ja_parallel_state_machine",   LG_JAPANESE,								TRUE },
-	{ N_("Korean"),				    "ko_parallel_state_machine",   LG_KOREAN,								TRUE },
-	{ N_("Russian"),			    "ruprob",			   LG_CYRILLIC | LG_UKRAINIAN,						TRUE },
-	{ N_("Universal"),	   		    "universal_charset_detector",  LG_ALL,								TRUE },
-	{ N_("Ukrainian"),	   		    "ukprob",			   LG_UKRAINIAN,							TRUE }
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("autodetectors|Off"),						    "",				   LG_NONE,								TRUE },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("automatically detect ... character encodings|Chinese"),		    "zh_parallel_state_machine",   LG_CHINESE_TRAD | LG_CHINESE_SIMP,					TRUE },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("automatically detect ... character encodings|Simplified Chinese"),    "zhcn_parallel_state_machine", LG_CHINESE_SIMP,							TRUE },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("automatically detect ... character encodings|Traditional Chinese"),   "zhtw_parallel_state_machine", LG_CHINESE_TRAD,							TRUE },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("automatically detect ... character encodings|East Asian"),	    "cjk_parallel_state_machine",  LG_CHINESE_TRAD | LG_CHINESE_SIMP | LG_JAPANESE | LG_KOREAN,		TRUE },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("automatically detect ... character encodings|Japanese"),		    "ja_parallel_state_machine",   LG_JAPANESE,								TRUE },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("automatically detect ... character encodings|Korean"),		    "ko_parallel_state_machine",   LG_KOREAN,								TRUE },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("automatically detect ... character encodings|Russian"),		    "ruprob",			   LG_CYRILLIC | LG_UKRAINIAN,						TRUE },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("automatically detect ... character encodings|Universal"),	   	    "universal_charset_detector",  LG_ALL,								TRUE },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("automatically detect ... character encodings|Ukrainian"),	   	    "ukprob",			   LG_UKRAINIAN,							TRUE }
 };
 static const guint n_encoding_entries = G_N_ELEMENTS (encoding_entries);
 
@@ -175,7 +196,7 @@ ephy_encodings_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyEncodingsClass),
 			NULL,
@@ -212,7 +233,7 @@ ephy_encodings_finalize (GObject *object)
 
 	g_object_unref (encodings->priv->db);
 
-	LOG ("EphyEncodings finalised")
+	LOG ("EphyEncodings finalised");
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -271,10 +292,8 @@ add_encoding (EphyEncodings *encodings,
 
 	node = ephy_node_new (encodings->priv->db);
 
-	g_value_init (&value, G_TYPE_STRING);
-	g_value_set_string (&value, title);
-	ephy_node_set_property (node, EPHY_NODE_ENCODING_PROP_TITLE, &value);
-	g_value_unset (&value);
+	ephy_node_set_property_string (node, EPHY_NODE_ENCODING_PROP_TITLE,
+				       title);
 
 	elided = elide_underscores (title);
 	normalised = g_utf8_normalize (elided, -1, G_NORMALIZE_DEFAULT);
@@ -291,20 +310,16 @@ add_encoding (EphyEncodings *encodings,
 	ephy_node_set_property (node, EPHY_NODE_ENCODING_PROP_TITLE_ELIDED, &value);
 	g_value_unset (&value);
 
-	g_value_init (&value, G_TYPE_STRING);
-	g_value_set_string (&value, code);
-	ephy_node_set_property (node, EPHY_NODE_ENCODING_PROP_ENCODING, &value);
-	g_value_unset (&value);
+	ephy_node_set_property_string (node, EPHY_NODE_ENCODING_PROP_ENCODING,
+				       code);
 
-	g_value_init (&value, G_TYPE_INT);
-	g_value_set_int (&value, groups);
-	ephy_node_set_property (node, EPHY_NODE_ENCODING_PROP_LANGUAGE_GROUPS, &value);
-	g_value_unset (&value);
-
-	g_value_init (&value, G_TYPE_BOOLEAN);
-	g_value_set_boolean (&value, is_autodetector);
-	ephy_node_set_property (node, EPHY_NODE_ENCODING_PROP_IS_AUTODETECTOR, &value);
-	g_value_unset (&value);
+	ephy_node_set_property_int (node,
+				    EPHY_NODE_ENCODING_PROP_LANGUAGE_GROUPS,
+				    groups);
+				    
+	ephy_node_set_property_boolean (node,
+					EPHY_NODE_ENCODING_PROP_IS_AUTODETECTOR,
+					is_autodetector);
 
 	/* now insert the node in our structure */
 	ephy_node_add_child (encodings->priv->root, node);
@@ -461,7 +476,7 @@ ephy_encodings_init (EphyEncodings *encodings)
 
 	encodings->priv = EPHY_ENCODINGS_GET_PRIVATE (encodings);
 
-	LOG ("EphyEncodings initialising")
+	LOG ("EphyEncodings initialising");
 
 	db = ephy_node_db_new ("EncodingsDB");
 	encodings->priv->db = db;
@@ -478,7 +493,9 @@ ephy_encodings_init (EphyEncodings *encodings)
 	for (i = 0; i < n_encoding_entries; i++)
 	{
 		add_encoding (encodings,
-			      _(encoding_entries[i].title),
+			      encoding_entries[i].is_autodetector
+			      	? Q_(encoding_entries[i].title)
+			 	: _(encoding_entries[i].title),
 			      encoding_entries[i].code,
 			      encoding_entries[i].groups,
 			      encoding_entries[i].is_autodetector);
