@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005, 2006 Christian Persch
+ *  Copyright © 2005, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyPromptService.cpp,v 1.14 2006/07/06 13:22:34 chpe Exp $
+ *  $Id: EphyPromptService.cpp 6588 2006-09-13 11:34:25Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -170,6 +170,8 @@ Prompter::Prompter (const char *aStock,
 	g_free (text);
 
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	/* Guard against overlong nonbreakable text (exploit) */
+	gtk_label_set_line_wrap_mode (GTK_LABEL (label), PANGO_WRAP_WORD_CHAR);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
 
