@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2004 Christian Persch
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,22 +16,20 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-event.cpp,v 1.9 2005/01/23 15:38:02 chpe Exp $
+ *  $Id: mozilla-embed-event.cpp 6588 2006-09-13 11:34:25Z chpe $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "mozilla-embed-event.h"
-
-#include "ephy-debug.h"
+#include <glib/ghash.h>
 
 #include <nsCOMPtr.h>
 #include <nsIDOMEvent.h>
 
-#include <glib/ghash.h>
-#include <gtk/gtktypeutils.h>
+#include "ephy-debug.h"
+
+#include "mozilla-embed-event.h"
 
 #define MOZILLA_EMBED_EVENT_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), MOZILLA_TYPE_EMBED_EVENT, MozillaEmbedEventPrivate))
 
@@ -54,7 +52,7 @@ mozilla_embed_event_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (MozillaEmbedEventClass),
 			NULL, /* base_init */
@@ -67,7 +65,7 @@ mozilla_embed_event_get_type (void)
 			(GInstanceInitFunc) mozilla_embed_event_init
 		};
 
-		static const GInterfaceInfo embed_event_info =
+		const GInterfaceInfo embed_event_info =
 		{
 			(GInterfaceInitFunc) ephy_embed_event_iface_init,
         		NULL,
@@ -140,12 +138,11 @@ impl_get_coordinates (EphyEmbedEvent *event,
 	*y = ((MozillaEmbedEvent *) event)->y;
 }
 
-static void
+static const GValue*
 impl_get_property (EphyEmbedEvent *event,
-		   const char *name,
-		   const GValue **value)
+		   const char *name)
 {
-	*value = (const GValue *) g_hash_table_lookup (((MozillaEmbedEvent *) event)->priv->props, name);
+	return (const GValue *) g_hash_table_lookup (((MozillaEmbedEvent *) event)->priv->props, name);
 }
 
 static gboolean
@@ -177,7 +174,7 @@ mozilla_embed_event_init (MozillaEmbedEvent *event)
 {
 	event->priv = MOZILLA_EMBED_EVENT_GET_PRIVATE (event);
 
-	LOG ("MozillaEmbedEvent %p initialising", event)
+	LOG ("MozillaEmbedEvent %p initialising", event);
 
 	event->priv->dom_event = nsnull;
 	event->priv->props = g_hash_table_new_full (g_str_hash, g_str_equal,
@@ -194,7 +191,7 @@ mozilla_embed_event_finalize (GObject *object)
 	NS_IF_RELEASE (event->priv->dom_event);
 	event->priv->dom_event = nsnull;
 
-	LOG ("MozillaEmbedEvent %p finalised", object)
+	LOG ("MozillaEmbedEvent %p finalised", object);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
