@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.83 2006/09/13 11:34:25 chpe Exp $
+ *  $Id: ephy-topic-action.c 6750 2006-12-17 19:19:09Z chpe $
  */
 
 #include "config.h"
@@ -296,6 +296,13 @@ button_deactivate_cb (GtkMenuShell *ms,
 {
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
 	gtk_button_released (GTK_BUTTON (button));
+
+	/*
+		Currently, GObject leaks connection IDs created with
+		g_signal_connect_object ()
+		See glib bug #118536
+	*/
+	g_signal_handlers_disconnect_by_func(ms, button_deactivate_cb, button);
 }
 
 static void
