@@ -15,12 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-completion-model.c 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: ephy-completion-model.c 6756 2006-12-18 12:35:02Z chpe $
  */
 
 #include "config.h"
 
 #include "ephy-completion-model.h"
+#include "ephy-favicon-cache.h"
 #include "ephy-node.h"
 #include "ephy-shell.h"
 #include "ephy-history.h"
@@ -271,8 +272,12 @@ ephy_completion_model_get_column_type (GtkTreeModel *tree_model,
 		case EPHY_COMPLETION_TEXT_COL:
 		case EPHY_COMPLETION_ACTION_COL:
 		case EPHY_COMPLETION_KEYWORDS_COL:
+		case EPHY_COMPLETION_EXTRA_COL:
 			type =  G_TYPE_STRING;
 			break;
+		case EPHY_COMPLETION_FAVICON_COL:
+			type = GDK_TYPE_PIXBUF;
+			break;
 		case EPHY_COMPLETION_RELEVANCE_COL:
 			type = G_TYPE_INT;
 			break;
@@ -346,6 +351,37 @@ init_keywords_col (GValue *value, EphyNode *node, int group)
 	
 	g_value_set_string (value, text);
 }
+static void
+init_favicon_col (GValue *value, EphyNode *node, int group)
+{
+	EphyFaviconCache *cache;
+	const char *icon_location;
+	GdkPixbuf *pixbuf = NULL;
+
+	cache = EPHY_FAVICON_CACHE
+		(ephy_embed_shell_get_favicon_cache (EPHY_EMBED_SHELL (ephy_shell)));
+
+	switch (group)
+	{
+		case BOOKMARKS_GROUP:
+			icon_location = ephy_node_get_property_string
+				(node, EPHY_NODE_BMK_PROP_ICON);
+			break;
+		case HISTORY_GROUP:
+			icon_location = ephy_node_get_property_string
+				(node, EPHY_NODE_PAGE_PROP_ICON);
+			break;
+		default:
+			icon_location = NULL;
+	}
+	
+	if (icon_location)
+	{
+		pixbuf = ephy_favicon_cache_get (cache, icon_location);
+	}
+
+	g_value_take_object (value, pixbuf);
+}
 
 static gboolean
 is_base_address (const char *address)
@@ -427,10 +463,25 @@ ephy_completion_model_get_value (GtkTreeModel *tree_model,
 
 	switch (column)
 	{
+		case EPHY_COMPLETION_EXTRA_COL:
+			g_value_init (value, G_TYPE_STRING);
+			/* We set an additional text for the item title only for history, since we assume that people know the url of their bookmarks */
+			if (group == HISTORY_GROUP)
+			{
+				const char *text;
+				text = ephy_node_get_property_string
+					(node, EPHY_NODE_PAGE_PROP_TITLE);
+				g_value_set_string (value, text);
+			}
+			break;
 		case EPHY_COMPLETION_TEXT_COL:
 			g_value_init (value, G_TYPE_STRING);
 			init_text_col (value, node, group);
 			break;
+		case EPHY_COMPLETION_FAVICON_COL:
+			g_value_init (value, GDK_TYPE_PIXBUF);
+			init_favicon_col (value, node, group);
+ 			break;
 		case EPHY_COMPLETION_ACTION_COL:
 			g_value_init (value, G_TYPE_STRING);
 			init_action_col (value, node, group);
