@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2002 Marco Pesenti Gritti
- *  Copyright (C) 2006 Christian Persch
+ *  Copyright © 2000-2002 Marco Pesenti Gritti
+ *  Copyright © 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-main.c,v 1.66 2006/04/13 19:25:52 chpe Exp $
+ *  $Id: ephy-main.c 6940 2007-03-05 19:17:20Z chpe $
  */
 
 #include "config.h"
@@ -60,7 +60,7 @@ static GQuark startup_error_quark = 0;
 static gboolean open_in_new_tab = FALSE;
 static gboolean open_in_new_window = FALSE;
 static gboolean open_as_bookmarks_editor = FALSE;
-//static gboolean reload_plugins = FALSE;
+/*static gboolean reload_plugins = FALSE;*/
 
 static char *session_filename = NULL;
 static char *bookmark_url = NULL;
@@ -91,7 +91,7 @@ static const GOptionEntry option_entries[] =
 	{ "profile", 0, 0, G_OPTION_ARG_STRING, &profile_directory,
 	  N_("Profile directory to use in the private instance"), N_("DIR") },
 	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &arguments,
-	  "", N_("URL ...")},
+	  "", N_("URL …")},
 	{ NULL }
 };
 
@@ -228,7 +228,7 @@ unref_proxy_reply_cb (DBusGProxy *proxy,
 	if (error != NULL)
 	{
 		g_warning ("An error occured while calling remote method: %s", error->message);
-		g_error_free (error);// FIXME???
+		g_error_free (error);/* FIXME??? */
 	}
 
 	g_object_unref (proxy);
@@ -427,6 +427,10 @@ main (int argc,
 	textdomain (GETTEXT_PACKAGE);
 #endif
 
+	/* Threads have to be initialised before calling ANY glib function */
+	g_thread_init (NULL);
+	dbus_g_thread_init ();
+
 	/* check libxml2 API version epiphany was compiled with against the
 	 * version we're running with.
 	 */
@@ -611,7 +615,7 @@ main (int argc,
 	g_set_application_name (_("Web Browser"));
 
 	/* Set default window icon */
-	gtk_window_set_default_icon_name ("web-browser");
+	gtk_window_set_default_icon_name (EPHY_STOCK_EPHY);
 
 	startup_error_quark = g_quark_from_static_string ("epiphany-startup-error");
 
@@ -679,7 +683,6 @@ main (int argc,
 	}
 
 	eel_gconf_monitor_add ("/apps/epiphany/general");
-	gnome_vfs_init ();
 	ephy_stock_icons_init ();
 
 	/* Extensions may want these, so don't initialize in window-cmds */
