@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.58 2006/09/13 11:34:23 chpe Exp $
+ *  $Id: ephy-session.c 6783 2007-01-03 08:08:12Z diegoe $
  */
 
 #include "config.h"
@@ -34,6 +34,8 @@
 #include "ephy-prefs.h"
 #include "ephy-gui.h"
 #include "ephy-debug.h"
+#include "ephy-stock-icons.h"
+#include "ephy-glib-compat.h"
 
 #include <glib/gi18n.h>
 #include <gtk/gtkmain.h>
@@ -282,7 +284,7 @@ confirm_shutdown_cb (GnomeClient *client,
 			       _("_Abort Downloads"), GTK_RESPONSE_ACCEPT);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
 
@@ -292,7 +294,7 @@ confirm_shutdown_cb (GnomeClient *client,
 	data->key = key;
 
 	/* This isn't very exact, but it's good enough here */
-	data->timeout_id = g_timeout_add (1000,
+	data->timeout_id = g_timeout_add_seconds (1,
 					  (GSourceFunc) confirm_shutdown_dialog_tick_cb,
 					  data);
 	data->ticks = 60;
@@ -617,7 +619,7 @@ session_command_autoresume (EphySession *session,
 			       _("_Recover"), GTK_RESPONSE_ACCEPT);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Crash Recovery"));
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), FALSE);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
